diff --git a/GamecraftModdingAPI.sln b/TechbloxModdingAPI.sln
similarity index 100%
rename from GamecraftModdingAPI.sln
rename to TechbloxModdingAPI.sln
diff --git a/TechbloxModdingAPI/App/AppEngine.cs b/TechbloxModdingAPI/App/AppEngine.cs
index d14f932..74c0d22 100644
--- a/TechbloxModdingAPI/App/AppEngine.cs
+++ b/TechbloxModdingAPI/App/AppEngine.cs
@@ -16,7 +16,7 @@ namespace TechbloxModdingAPI.App
public IEntityFactory Factory { set; private get; }
- public string Name => "GamecraftModdingAPIAppEngine";
+ public string Name => "TechbloxModdingAPIAppEngine";
public bool isRemovable => false;
diff --git a/TechbloxModdingAPI/App/AppExceptions.cs b/TechbloxModdingAPI/App/AppExceptions.cs
index b3393cb..dfe3afe 100644
--- a/TechbloxModdingAPI/App/AppExceptions.cs
+++ b/TechbloxModdingAPI/App/AppExceptions.cs
@@ -3,7 +3,7 @@ using System.Runtime.Serialization;
namespace TechbloxModdingAPI.App
{
- public class AppException : GamecraftModdingAPIException
+ public class AppException : TechbloxModdingAPIException
{
public AppException()
{
diff --git a/TechbloxModdingAPI/App/Client.cs b/TechbloxModdingAPI/App/Client.cs
index 4887448..420f004 100644
--- a/TechbloxModdingAPI/App/Client.cs
+++ b/TechbloxModdingAPI/App/Client.cs
@@ -10,7 +10,7 @@ using TechbloxModdingAPI.Utility;
namespace TechbloxModdingAPI.App
{
///
- /// The Gamecraft application that is running this code right now.
+ /// The Techblox application that is running this code right now.
///
public class Client
{
@@ -42,7 +42,7 @@ namespace TechbloxModdingAPI.App
}
///
- /// Gamecraft build version string.
+ /// Techblox build version string.
/// Usually this is in the form YYYY.mm.DD.HH.MM.SS
///
/// The version.
@@ -75,7 +75,7 @@ namespace TechbloxModdingAPI.App
}
///
- /// Whether Gamecraft is in the Main Menu
+ /// Whether Techblox is in the Main Menu
///
/// true if in menu; false when loading or in a game.
public bool InMenu
@@ -85,7 +85,7 @@ namespace TechbloxModdingAPI.App
///
/// Open a popup which prompts the user to click a button.
- /// This reuses Gamecraft's error dialog popup
+ /// This reuses Techblox's error dialog popup
///
/// The popup to display. Use an instance of SingleChoicePrompt or DualChoicePrompt.
public void PromptUser(Error popup)
diff --git a/TechbloxModdingAPI/App/Game.cs b/TechbloxModdingAPI/App/Game.cs
index a3099eb..252171d 100644
--- a/TechbloxModdingAPI/App/Game.cs
+++ b/TechbloxModdingAPI/App/Game.cs
@@ -118,7 +118,7 @@ namespace TechbloxModdingAPI.App
///
/// An event that fires right before a game returns to the main menu.
- /// At this point, Gamecraft is transitioning state so many things are invalid/unstable here.
+ /// At this point, Techblox is transitioning state so many things are invalid/unstable here.
///
public static event EventHandler Exit
{
diff --git a/TechbloxModdingAPI/App/GameBuildSimEventEngine.cs b/TechbloxModdingAPI/App/GameBuildSimEventEngine.cs
index f4b5766..f710d6f 100644
--- a/TechbloxModdingAPI/App/GameBuildSimEventEngine.cs
+++ b/TechbloxModdingAPI/App/GameBuildSimEventEngine.cs
@@ -15,7 +15,7 @@ namespace TechbloxModdingAPI.App
public event EventHandler BuildMode;
- public string Name => "GamecraftModdingAPIBuildSimEventGameEngine";
+ public string Name => "TechbloxModdingAPIBuildSimEventGameEngine";
public bool isRemovable => false;
diff --git a/TechbloxModdingAPI/App/GameGameEngine.cs b/TechbloxModdingAPI/App/GameGameEngine.cs
index d5a2f60..1ed4d48 100644
--- a/TechbloxModdingAPI/App/GameGameEngine.cs
+++ b/TechbloxModdingAPI/App/GameGameEngine.cs
@@ -22,7 +22,7 @@ namespace TechbloxModdingAPI.App
public event EventHandler ExitGame;
- public string Name => "GamecraftModdingAPIGameInfoMenuEngine";
+ public string Name => "TechbloxModdingAPIGameInfoMenuEngine";
public bool isRemovable => false;
diff --git a/TechbloxModdingAPI/App/GameMenuEngine.cs b/TechbloxModdingAPI/App/GameMenuEngine.cs
index 9fce3b7..3357984 100644
--- a/TechbloxModdingAPI/App/GameMenuEngine.cs
+++ b/TechbloxModdingAPI/App/GameMenuEngine.cs
@@ -17,7 +17,7 @@ namespace TechbloxModdingAPI.App
{
public IEntityFactory Factory { set; private get; }
- public string Name => "GamecraftModdingAPIGameInfoGameEngine";
+ public string Name => "TechbloxModdingAPIGameInfoGameEngine";
public bool isRemovable => false;
diff --git a/TechbloxModdingAPI/Blocks/BlockCloneEngine.cs b/TechbloxModdingAPI/Blocks/BlockCloneEngine.cs
index 8703953..e1501e8 100644
--- a/TechbloxModdingAPI/Blocks/BlockCloneEngine.cs
+++ b/TechbloxModdingAPI/Blocks/BlockCloneEngine.cs
@@ -100,7 +100,7 @@ namespace TechbloxModdingAPI.Blocks
}
}
- public string Name { get; } = "GamecraftModdingAPIBlockCloneGameEngine";
+ public string Name { get; } = "TechbloxModdingAPIBlockCloneGameEngine";
public bool isRemovable { get; } = false;
}
}
\ No newline at end of file
diff --git a/TechbloxModdingAPI/Blocks/BlockEngine.cs b/TechbloxModdingAPI/Blocks/BlockEngine.cs
index 956871b..404e72a 100644
--- a/TechbloxModdingAPI/Blocks/BlockEngine.cs
+++ b/TechbloxModdingAPI/Blocks/BlockEngine.cs
@@ -24,7 +24,7 @@ namespace TechbloxModdingAPI.Blocks
///
public partial class BlockEngine : IApiEngine
{
- public string Name { get; } = "GamecraftModdingAPIBlockGameEngine";
+ public string Name { get; } = "TechbloxModdingAPIBlockGameEngine";
public EntitiesDB entitiesDB { set; private get; }
diff --git a/TechbloxModdingAPI/Blocks/BlockEventsEngine.cs b/TechbloxModdingAPI/Blocks/BlockEventsEngine.cs
index f89768b..3b77075 100644
--- a/TechbloxModdingAPI/Blocks/BlockEventsEngine.cs
+++ b/TechbloxModdingAPI/Blocks/BlockEventsEngine.cs
@@ -23,7 +23,7 @@ namespace TechbloxModdingAPI.Blocks
{
}
- public string Name { get; } = "GamecraftModdingAPIBlockEventsEngine";
+ public string Name { get; } = "TechbloxModdingAPIBlockEventsEngine";
public bool isRemovable { get; } = false;
private bool shouldAddRemove;
diff --git a/TechbloxModdingAPI/Blocks/BlockExceptions.cs b/TechbloxModdingAPI/Blocks/BlockExceptions.cs
index 409bb02..4029185 100644
--- a/TechbloxModdingAPI/Blocks/BlockExceptions.cs
+++ b/TechbloxModdingAPI/Blocks/BlockExceptions.cs
@@ -4,7 +4,7 @@ using TechbloxModdingAPI;
namespace TechbloxModdingAPI.Blocks
{
- public class BlockException : GamecraftModdingAPIException
+ public class BlockException : TechbloxModdingAPIException
{
public BlockException()
{
diff --git a/TechbloxModdingAPI/Blocks/BlockIDs.cs b/TechbloxModdingAPI/Blocks/BlockIDs.cs
index 30fa76f..fcb3e41 100644
--- a/TechbloxModdingAPI/Blocks/BlockIDs.cs
+++ b/TechbloxModdingAPI/Blocks/BlockIDs.cs
@@ -6,7 +6,7 @@ namespace TechbloxModdingAPI.Blocks
public enum BlockIDs : ushort
{
///
- /// Called "nothing" in Gamecraft. (DBID.NOTHING)
+ /// Called "nothing" in Techblox. (DBID.NOTHING)
///
Invalid = ushort.MaxValue,
Cube = 0,
diff --git a/TechbloxModdingAPI/Blocks/BlueprintEngine.cs b/TechbloxModdingAPI/Blocks/BlueprintEngine.cs
index 19e0afc..a6f65f3 100644
--- a/TechbloxModdingAPI/Blocks/BlueprintEngine.cs
+++ b/TechbloxModdingAPI/Blocks/BlueprintEngine.cs
@@ -248,7 +248,7 @@ namespace TechbloxModdingAPI.Blocks
clipboardManager.DecrementRefCount(blueprintID);
}
- public string Name { get; } = "GamecraftModdingAPIBlueprintGameEngine";
+ public string Name { get; } = "TechbloxModdingAPIBlueprintGameEngine";
public bool isRemovable { get; } = false;
[HarmonyPatch]
diff --git a/TechbloxModdingAPI/Blocks/CustomBlockEngine.cs b/TechbloxModdingAPI/Blocks/CustomBlockEngine.cs
index ef3c1e5..b8132a2 100644
--- a/TechbloxModdingAPI/Blocks/CustomBlockEngine.cs
+++ b/TechbloxModdingAPI/Blocks/CustomBlockEngine.cs
@@ -14,7 +14,7 @@ namespace TechbloxModdingAPI.Blocks
{
public class CustomBlockEntityDescriptor : SerializableEntityDescriptor
{
- [HashName("GamecraftModdingAPICustomBlockV0")]
+ [HashName("TechbloxModdingAPICustomBlockV0")]
public class _CustomBlockDescriptor : IEntityDescriptor
{
public IComponentBuilder[] componentsToBuild { get; } =
@@ -57,7 +57,7 @@ namespace TechbloxModdingAPI.Blocks
_registeredBlocks.Add((id, name));
}
- public string Name { get; } = "GamecraftModdingAPICustomBlockEngine";
+ public string Name { get; } = "TechbloxModdingAPICustomBlockEngine";
public bool isRemovable { get; } = false;
public IEntityFactory Factory { get; set; }
}*/
diff --git a/TechbloxModdingAPI/Blocks/MovementEngine.cs b/TechbloxModdingAPI/Blocks/MovementEngine.cs
index b01b714..aeeac20 100644
--- a/TechbloxModdingAPI/Blocks/MovementEngine.cs
+++ b/TechbloxModdingAPI/Blocks/MovementEngine.cs
@@ -14,7 +14,7 @@ namespace TechbloxModdingAPI.Blocks
///
public class MovementEngine : IApiEngine
{
- public string Name { get; } = "GamecraftModdingAPIMovementGameEngine";
+ public string Name { get; } = "TechbloxModdingAPIMovementGameEngine";
public EntitiesDB entitiesDB { set; private get; }
diff --git a/TechbloxModdingAPI/Blocks/PlacementEngine.cs b/TechbloxModdingAPI/Blocks/PlacementEngine.cs
index 38e27f1..afd5574 100644
--- a/TechbloxModdingAPI/Blocks/PlacementEngine.cs
+++ b/TechbloxModdingAPI/Blocks/PlacementEngine.cs
@@ -80,7 +80,7 @@ namespace TechbloxModdingAPI.Blocks
return structInitializer;
}
- public string Name => "GamecraftModdingAPIPlacementGameEngine";
+ public string Name => "TechbloxModdingAPIPlacementGameEngine";
public bool isRemovable => false;
diff --git a/TechbloxModdingAPI/Blocks/RemovalEngine.cs b/TechbloxModdingAPI/Blocks/RemovalEngine.cs
index 08216fc..858cb8f 100644
--- a/TechbloxModdingAPI/Blocks/RemovalEngine.cs
+++ b/TechbloxModdingAPI/Blocks/RemovalEngine.cs
@@ -38,7 +38,7 @@ namespace TechbloxModdingAPI.Blocks
{
}
- public string Name { get; } = "GamecraftModdingAPIRemovalGameEngine";
+ public string Name { get; } = "TechbloxModdingAPIRemovalGameEngine";
public bool isRemovable => false;
diff --git a/TechbloxModdingAPI/Blocks/RotationEngine.cs b/TechbloxModdingAPI/Blocks/RotationEngine.cs
index 1f35d17..cef4691 100644
--- a/TechbloxModdingAPI/Blocks/RotationEngine.cs
+++ b/TechbloxModdingAPI/Blocks/RotationEngine.cs
@@ -14,7 +14,7 @@ namespace TechbloxModdingAPI.Blocks
///
public class RotationEngine : IApiEngine
{
- public string Name { get; } = "GamecraftModdingAPIRotationGameEngine";
+ public string Name { get; } = "TechbloxModdingAPIRotationGameEngine";
public EntitiesDB entitiesDB { set; private get; }
diff --git a/TechbloxModdingAPI/Blocks/ScalingEngine.cs b/TechbloxModdingAPI/Blocks/ScalingEngine.cs
index 81131e6..7485f7e 100644
--- a/TechbloxModdingAPI/Blocks/ScalingEngine.cs
+++ b/TechbloxModdingAPI/Blocks/ScalingEngine.cs
@@ -23,7 +23,7 @@ namespace TechbloxModdingAPI.Blocks
{
}
- public string Name { get; } = "GamecraftModdingAPIScalingEngine";
+ public string Name { get; } = "TechbloxModdingAPIScalingEngine";
public bool isRemovable { get; } = false;
private EntityManager _entityManager; //Unity entity manager
diff --git a/TechbloxModdingAPI/Blocks/SignalEngine.cs b/TechbloxModdingAPI/Blocks/SignalEngine.cs
index 3b1cf6a..6e40af1 100644
--- a/TechbloxModdingAPI/Blocks/SignalEngine.cs
+++ b/TechbloxModdingAPI/Blocks/SignalEngine.cs
@@ -16,7 +16,7 @@ namespace TechbloxModdingAPI.Blocks
public const float HIGH = 1.0f;
public const float ZERO = 0.0f;
- public string Name { get; } = "GamecraftModdingAPISignalGameEngine";
+ public string Name { get; } = "TechbloxModdingAPISignalGameEngine";
public EntitiesDB entitiesDB { set; private get; }
diff --git a/TechbloxModdingAPI/Commands/CommandExceptions.cs b/TechbloxModdingAPI/Commands/CommandExceptions.cs
index 4141a9f..b860093 100644
--- a/TechbloxModdingAPI/Commands/CommandExceptions.cs
+++ b/TechbloxModdingAPI/Commands/CommandExceptions.cs
@@ -1,7 +1,7 @@
using System;
namespace TechbloxModdingAPI.Commands
{
- public class CommandException : GamecraftModdingAPIException
+ public class CommandException : TechbloxModdingAPIException
{
public CommandException() : base() {}
diff --git a/TechbloxModdingAPI/Commands/CommandRegistrationHelper.cs b/TechbloxModdingAPI/Commands/CommandRegistrationHelper.cs
index 633bf75..850322a 100644
--- a/TechbloxModdingAPI/Commands/CommandRegistrationHelper.cs
+++ b/TechbloxModdingAPI/Commands/CommandRegistrationHelper.cs
@@ -10,7 +10,7 @@ using RobocraftX.CommandLine.Custom;
namespace TechbloxModdingAPI.Commands
{
///
- /// Convenient methods for registering commands to Gamecraft.
+ /// Convenient methods for registering commands to Techblox.
/// All methods register to the command line and console block by default.
///
public static class CommandRegistrationHelper
diff --git a/TechbloxModdingAPI/Events/EventExceptions.cs b/TechbloxModdingAPI/Events/EventExceptions.cs
index a796752..1b1d5b3 100644
--- a/TechbloxModdingAPI/Events/EventExceptions.cs
+++ b/TechbloxModdingAPI/Events/EventExceptions.cs
@@ -1,7 +1,7 @@
using System;
namespace TechbloxModdingAPI.Events
{
- public class EventException : GamecraftModdingAPIException
+ public class EventException : TechbloxModdingAPIException
{
public EventException()
{
diff --git a/TechbloxModdingAPI/Events/GameActivatedComposePatch.cs b/TechbloxModdingAPI/Events/GameActivatedComposePatch.cs
index 62b5666..8a32f37 100644
--- a/TechbloxModdingAPI/Events/GameActivatedComposePatch.cs
+++ b/TechbloxModdingAPI/Events/GameActivatedComposePatch.cs
@@ -34,18 +34,18 @@ namespace TechbloxModdingAPI.Events
// so all event emitters and handlers must be re-registered.
EventManager.RegisterEngines(enginesRoot);
Logging.Log("Dispatching Game Activated event");
- EventManager.GetEventEmitter("GamecraftModdingAPIGameActivatedEventEmitter").Emit();
+ EventManager.GetEventEmitter("TechbloxModdingAPIGameActivatedEventEmitter").Emit();
if (IsGameSwitching)
{
IsGameSwitching = false;
Logging.Log("Dispatching Game Switched To event");
- EventManager.GetEventEmitter("GamecraftModdingAPIGameSwitchedToEventEmitter").Emit();
+ EventManager.GetEventEmitter("TechbloxModdingAPIGameSwitchedToEventEmitter").Emit();
}
if (IsGameReloading)
{
IsGameReloading = false;
Logging.Log("Dispatching Game Reloaded event");
- EventManager.GetEventEmitter("GamecraftModdingAPIGameReloadedEventEmitter").Emit();
+ EventManager.GetEventEmitter("TechbloxModdingAPIGameReloadedEventEmitter").Emit();
}
}
diff --git a/TechbloxModdingAPI/Events/GameStateBuildEmitterEngine.cs b/TechbloxModdingAPI/Events/GameStateBuildEmitterEngine.cs
index 29fb418..8dd5d8b 100644
--- a/TechbloxModdingAPI/Events/GameStateBuildEmitterEngine.cs
+++ b/TechbloxModdingAPI/Events/GameStateBuildEmitterEngine.cs
@@ -14,7 +14,7 @@ namespace TechbloxModdingAPI.Events
[Obsolete]
public class GameStateBuildEmitterEngine : IEventEmitterEngine, IUnorderedInitializeOnTimeStoppedModeEntered
{
- public string Name { get; } = "GamecraftModdingAPIGameStateBuildEventEmitter" ;
+ public string Name { get; } = "TechbloxModdingAPIGameStateBuildEventEmitter" ;
public EntitiesDB entitiesDB { set; private get; }
diff --git a/TechbloxModdingAPI/Events/GameStateSimulationEmitterEngine.cs b/TechbloxModdingAPI/Events/GameStateSimulationEmitterEngine.cs
index add45d5..c682812 100644
--- a/TechbloxModdingAPI/Events/GameStateSimulationEmitterEngine.cs
+++ b/TechbloxModdingAPI/Events/GameStateSimulationEmitterEngine.cs
@@ -14,7 +14,7 @@ namespace TechbloxModdingAPI.Events
[Obsolete]
public class GameStateSimulationEmitterEngine : IEventEmitterEngine, IUnorderedInitializeOnTimeRunningModeEntered
{
- public string Name { get; } = "GamecraftModdingAPIGameStateSimulationEventEmitter" ;
+ public string Name { get; } = "TechbloxModdingAPIGameStateSimulationEventEmitter" ;
public EntitiesDB entitiesDB { set; private get; }
diff --git a/TechbloxModdingAPI/Events/MenuActivatedPatch.cs b/TechbloxModdingAPI/Events/MenuActivatedPatch.cs
index 64aa57f..0951752 100644
--- a/TechbloxModdingAPI/Events/MenuActivatedPatch.cs
+++ b/TechbloxModdingAPI/Events/MenuActivatedPatch.cs
@@ -33,10 +33,10 @@ namespace TechbloxModdingAPI.Events
FullGameFields.Init(__instance);
//Application.Application.SetFullGameCompositionRoot(__instance);
Logging.Log("Dispatching App Init event");
- EventManager.GetEventEmitter("GamecraftModdingAPIApplicationInitializedEventEmitter").Emit();
+ EventManager.GetEventEmitter("TechbloxModdingAPIApplicationInitializedEventEmitter").Emit();
}
Logging.Log("Dispatching Menu Activated event");
- EventManager.GetEventEmitter("GamecraftModdingAPIMenuActivatedEventEmitter").Emit();
+ EventManager.GetEventEmitter("TechbloxModdingAPIMenuActivatedEventEmitter").Emit();
}
}
}
diff --git a/TechbloxModdingAPI/Events/MenuSwitchedToPatch.cs b/TechbloxModdingAPI/Events/MenuSwitchedToPatch.cs
index c8fec0a..23c4b77 100644
--- a/TechbloxModdingAPI/Events/MenuSwitchedToPatch.cs
+++ b/TechbloxModdingAPI/Events/MenuSwitchedToPatch.cs
@@ -22,7 +22,7 @@ namespace TechbloxModdingAPI.Events
{
// Event emitters and handlers should already be registered by MenuActivated event
Logging.Log("Dispatching Menu Switched To event");
- EventManager.GetEventEmitter("GamecraftModdingAPIMenuSwitchedToEventEmitter").Emit();
+ EventManager.GetEventEmitter("TechbloxModdingAPIMenuSwitchedToEventEmitter").Emit();
}
}
}
diff --git a/TechbloxModdingAPI/GamecraftModdingAPIException.cs b/TechbloxModdingAPI/GamecraftModdingAPIException.cs
index 0b4f7d5..3a1b73f 100644
--- a/TechbloxModdingAPI/GamecraftModdingAPIException.cs
+++ b/TechbloxModdingAPI/GamecraftModdingAPIException.cs
@@ -3,21 +3,21 @@ using System.Runtime.Serialization;
namespace TechbloxModdingAPI
{
- public class GamecraftModdingAPIException : Exception
+ public class TechbloxModdingAPIException : Exception
{
- public GamecraftModdingAPIException()
+ public TechbloxModdingAPIException()
{
}
- public GamecraftModdingAPIException(string message) : base(message)
+ public TechbloxModdingAPIException(string message) : base(message)
{
}
- public GamecraftModdingAPIException(string message, Exception innerException) : base(message, innerException)
+ public TechbloxModdingAPIException(string message, Exception innerException) : base(message, innerException)
{
}
- protected GamecraftModdingAPIException(SerializationInfo info, StreamingContext context) : base(info, context)
+ protected TechbloxModdingAPIException(SerializationInfo info, StreamingContext context) : base(info, context)
{
}
}
diff --git a/TechbloxModdingAPI/Input/FakeInputEngine.cs b/TechbloxModdingAPI/Input/FakeInputEngine.cs
index 0a41fb2..7d2efb7 100644
--- a/TechbloxModdingAPI/Input/FakeInputEngine.cs
+++ b/TechbloxModdingAPI/Input/FakeInputEngine.cs
@@ -12,7 +12,7 @@ namespace TechbloxModdingAPI.Input
{
public class FakeInputEngine : IApiEngine
{
- public string Name { get; } = "GamecraftModdingAPIFakeInputEngine";
+ public string Name { get; } = "TechbloxModdingAPIFakeInputEngine";
public EntitiesDB entitiesDB { set; private get; }
diff --git a/TechbloxModdingAPI/Interface/IMGUI/IMGUIManager.cs b/TechbloxModdingAPI/Interface/IMGUI/IMGUIManager.cs
index d4f3bb7..8b3c865 100644
--- a/TechbloxModdingAPI/Interface/IMGUI/IMGUIManager.cs
+++ b/TechbloxModdingAPI/Interface/IMGUI/IMGUIManager.cs
@@ -20,7 +20,7 @@ namespace TechbloxModdingAPI.Interface.IMGUI
///
public static class IMGUIManager
{
- internal static OnGuiRunner ImguiScheduler = new OnGuiRunner("GamecraftModdingAPI_IMGUIScheduler");
+ internal static OnGuiRunner ImguiScheduler = new OnGuiRunner("TechbloxModdingAPI_IMGUIScheduler");
private static Dictionary _activeElements = new Dictionary();
diff --git a/TechbloxModdingAPI/Inventory/HotbarEngine.cs b/TechbloxModdingAPI/Inventory/HotbarEngine.cs
index 764f535..66f8c78 100644
--- a/TechbloxModdingAPI/Inventory/HotbarEngine.cs
+++ b/TechbloxModdingAPI/Inventory/HotbarEngine.cs
@@ -18,7 +18,7 @@ namespace TechbloxModdingAPI.Inventory
{
public class HotbarEngine : IApiEngine
{
- public string Name { get; } = "GamecraftModdingAPIHotbarGameEngine";
+ public string Name { get; } = "TechbloxModdingAPIHotbarGameEngine";
public EntitiesDB entitiesDB { set; private get; }
diff --git a/TechbloxModdingAPI/Persistence/DeserializeFromDiskEntitiesEnginePatch.cs b/TechbloxModdingAPI/Persistence/DeserializeFromDiskEntitiesEnginePatch.cs
index f436e56..d998f0e 100644
--- a/TechbloxModdingAPI/Persistence/DeserializeFromDiskEntitiesEnginePatch.cs
+++ b/TechbloxModdingAPI/Persistence/DeserializeFromDiskEntitiesEnginePatch.cs
@@ -17,7 +17,7 @@ namespace TechbloxModdingAPI.Persistence
{
internal static EntitiesDB entitiesDB = null;
- private static readonly byte[] frameStart = Encoding.UTF8.GetBytes("\0\0\0GamecraftModdingAPI\0\0\0");
+ private static readonly byte[] frameStart = Encoding.UTF8.GetBytes("\0\0\0TechbloxModdingAPI\0\0\0");
public static void Prefix(ref ISerializationData ____serializationData, ref FasterList ____bytesStream, ref IEntitySerialization ____entitySerializer, bool ____spawnBlocksOnly)
{
diff --git a/TechbloxModdingAPI/Persistence/IEntitySerializer.cs b/TechbloxModdingAPI/Persistence/IEntitySerializer.cs
index e7fcd5c..0d6e599 100644
--- a/TechbloxModdingAPI/Persistence/IEntitySerializer.cs
+++ b/TechbloxModdingAPI/Persistence/IEntitySerializer.cs
@@ -8,7 +8,7 @@ using TechbloxModdingAPI.Utility;
namespace TechbloxModdingAPI.Persistence
{
///
- /// Entity serializer and deserializer interface for storing and retrieving data in a Gamecraft save file (GameSave.GC).
+ /// Entity serializer and deserializer interface for storing and retrieving data in a Techblox save file (GameSave.GC).
///
public interface IEntitySerializer : IDeserializationFactory, IQueryingEntitiesEngine
{
diff --git a/TechbloxModdingAPI/Persistence/SaveGameEnginePatch.cs b/TechbloxModdingAPI/Persistence/SaveGameEnginePatch.cs
index 74edddf..9371e9b 100644
--- a/TechbloxModdingAPI/Persistence/SaveGameEnginePatch.cs
+++ b/TechbloxModdingAPI/Persistence/SaveGameEnginePatch.cs
@@ -15,7 +15,7 @@ namespace TechbloxModdingAPI.Persistence
//[HarmonyPatch] - TODO
class SaveGameEnginePatch
{
- private static readonly byte[] frameStart = Encoding.UTF8.GetBytes("\0\0\0GamecraftModdingAPI\0\0\0");
+ private static readonly byte[] frameStart = Encoding.UTF8.GetBytes("\0\0\0TechbloxModdingAPI\0\0\0");
public static void Postfix(ref ISerializationData serializationData, EntitiesDB entitiesDB, IEntitySerialization entitySerializer)
{
diff --git a/TechbloxModdingAPI/Persistence/SerializerManager.cs b/TechbloxModdingAPI/Persistence/SerializerManager.cs
index 6177d7c..04079cf 100644
--- a/TechbloxModdingAPI/Persistence/SerializerManager.cs
+++ b/TechbloxModdingAPI/Persistence/SerializerManager.cs
@@ -11,7 +11,7 @@ namespace TechbloxModdingAPI.Persistence
///
/// Keeps track of serializers.
/// This is used to add and retrieve serializers.
- /// Added IEntitySerializations are used in serializing and deserializing Gamecraft save files (GameSave.GC).
+ /// Added IEntitySerializations are used in serializing and deserializing Techblox save files (GameSave.GC).
///
public static class SerializerManager
{
diff --git a/TechbloxModdingAPI/Players/PlayerEngine.cs b/TechbloxModdingAPI/Players/PlayerEngine.cs
index cc24650..d71c3ee 100644
--- a/TechbloxModdingAPI/Players/PlayerEngine.cs
+++ b/TechbloxModdingAPI/Players/PlayerEngine.cs
@@ -26,7 +26,7 @@ namespace TechbloxModdingAPI.Players
{
internal class PlayerEngine : IApiEngine, IFactoryEngine
{
- public string Name { get; } = "GamecraftModdingAPIPlayerGameEngine";
+ public string Name { get; } = "TechbloxModdingAPIPlayerGameEngine";
public EntitiesDB entitiesDB { set; private get; }
diff --git a/TechbloxModdingAPI/Players/PlayerExceptions.cs b/TechbloxModdingAPI/Players/PlayerExceptions.cs
index d5bba55..20dbea6 100644
--- a/TechbloxModdingAPI/Players/PlayerExceptions.cs
+++ b/TechbloxModdingAPI/Players/PlayerExceptions.cs
@@ -1,7 +1,7 @@
using System;
namespace TechbloxModdingAPI.Players
{
- public class PlayerException : GamecraftModdingAPIException
+ public class PlayerException : TechbloxModdingAPIException
{
public PlayerException()
{
diff --git a/TechbloxModdingAPI/TechbloxModdingAPI.csproj b/TechbloxModdingAPI/TechbloxModdingAPI.csproj
index 4624c80..bd4135c 100644
--- a/TechbloxModdingAPI/TechbloxModdingAPI.csproj
+++ b/TechbloxModdingAPI/TechbloxModdingAPI.csproj
@@ -8,7 +8,6 @@
https://git.exmods.org/modtainers/GamecraftModdingAPI
en-CA
true
- GamecraftModdingAPI
diff --git a/TechbloxModdingAPI/Tests/GamecraftModdingAPIPluginTest.cs b/TechbloxModdingAPI/Tests/GamecraftModdingAPIPluginTest.cs
index 292f769..2274600 100644
--- a/TechbloxModdingAPI/Tests/GamecraftModdingAPIPluginTest.cs
+++ b/TechbloxModdingAPI/Tests/GamecraftModdingAPIPluginTest.cs
@@ -55,7 +55,7 @@ namespace TechbloxModdingAPI.Tests
/// Modding API implemented as a standalone IPA Plugin.
/// Ideally, TechbloxModdingAPI should be loaded by another mod; not itself
///
- public class GamecraftModdingAPIPluginTest : IllusionPlugin.IEnhancedPlugin
+ public class TechbloxModdingAPIPluginTest : IllusionPlugin.IEnhancedPlugin
{
private static Harmony harmony { get; set; }
@@ -64,7 +64,7 @@ namespace TechbloxModdingAPI.Tests
public override string Version { get; } = Assembly.GetExecutingAssembly().GetName().Version.ToString();
- public string HarmonyID { get; } = "org.git.exmods.modtainers.gamecraftmoddingapi";
+ public string HarmonyID { get; } = "org.git.exmods.modtainers.techbloxmoddingapi";
public override void OnApplicationQuit()
{
@@ -367,16 +367,16 @@ namespace TechbloxModdingAPI.Tests
}
// dependency test
- if (Dependency.Hell("GamecraftScripting", new Version("0.0.1.0")))
+ if (Dependency.Hell("TechbloxScripting", new Version("0.0.1.0")))
{
- Logging.LogWarning("You're in GamecraftScripting dependency hell");
+ Logging.LogWarning("You're in TechbloxScripting dependency hell");
}
else
{
- Logging.Log("Compatible GamecraftScripting detected");
+ Logging.Log("Compatible TechbloxScripting detected");
}
// Interface test
- /*Interface.IMGUI.Group uiGroup = new Group(new Rect(20, 20, 200, 500), "GamecraftModdingAPI_UITestGroup", true);
+ /*Interface.IMGUI.Group uiGroup = new Group(new Rect(20, 20, 200, 500), "TechbloxModdingAPI_UITestGroup", true);
Interface.IMGUI.Button button = new Button("TEST");
button.OnClick += (b, __) => { Logging.MetaDebugLog($"Click on {((Interface.IMGUI.Button)b).Name}");};
Interface.IMGUI.Button button2 = new Button("TEST2");
diff --git a/TechbloxModdingAPI/Tests/TestRoot.cs b/TechbloxModdingAPI/Tests/TestRoot.cs
index 878fdda..9085470 100644
--- a/TechbloxModdingAPI/Tests/TestRoot.cs
+++ b/TechbloxModdingAPI/Tests/TestRoot.cs
@@ -21,7 +21,7 @@ namespace TechbloxModdingAPI.Tests
{
public static bool AutoShutdown = true;
- public const string ReportFile = "GamecraftModdingAPI_tests.log";
+ public const string ReportFile = "TechbloxModdingAPI_tests.log";
private static bool _testsPassed = false;
@@ -283,7 +283,7 @@ namespace TechbloxModdingAPI.Tests
Logging.MetaLog("Starting test run");
// log metadata
Assert.Log($"Unity {Application.unityVersion}");
- Assert.Log($"Gamecraft {Application.version}");
+ Assert.Log($"Techblox {Application.version}");
Assert.Log($"TechbloxModdingAPI {Assembly.GetExecutingAssembly().GetName().Version}");
Assert.Log($"Testing {asm.GetName().Name} {asm.GetName().Version}");
Assert.Log($"START: --- {DateTime.Now.ToString()} --- ({testTypes.Count} tests classes detected)");
diff --git a/TechbloxModdingAPI/Utility/AsyncUtilsEngine.cs b/TechbloxModdingAPI/Utility/AsyncUtilsEngine.cs
index b9e6ad3..ee18ced 100644
--- a/TechbloxModdingAPI/Utility/AsyncUtilsEngine.cs
+++ b/TechbloxModdingAPI/Utility/AsyncUtilsEngine.cs
@@ -57,7 +57,7 @@ namespace TechbloxModdingAPI.Utility
{
}
- public string Name { get; } = "GamecraftModdingAPIAsyncUtilsGameEngine";
+ public string Name { get; } = "TechbloxModdingAPIAsyncUtilsGameEngine";
public bool isRemovable { get; } = false;
}
}
\ No newline at end of file
diff --git a/TechbloxModdingAPI/Utility/DebugInterfaceEngine.cs b/TechbloxModdingAPI/Utility/DebugInterfaceEngine.cs
index 24d59b3..7f9d97c 100644
--- a/TechbloxModdingAPI/Utility/DebugInterfaceEngine.cs
+++ b/TechbloxModdingAPI/Utility/DebugInterfaceEngine.cs
@@ -31,7 +31,7 @@ namespace TechbloxModdingAPI.Utility
public void SetInfo(string id, Func contentGetter) => _extraInfo[id] = contentGetter;
public bool RemoveInfo(string id) => _extraInfo.Remove(id);
- public string Name => "GamecraftModdingAPIDebugInterfaceGameEngine";
+ public string Name => "TechbloxModdingAPIDebugInterfaceGameEngine";
public bool isRemovable => true;
[HarmonyPatch]
diff --git a/TechbloxModdingAPI/Utility/GameState.cs b/TechbloxModdingAPI/Utility/GameState.cs
index 50dfb83..79a72fe 100644
--- a/TechbloxModdingAPI/Utility/GameState.cs
+++ b/TechbloxModdingAPI/Utility/GameState.cs
@@ -7,7 +7,7 @@ using System.Threading.Tasks;
namespace TechbloxModdingAPI.Utility
{
///
- /// Utility to get the state of the current Gamecraft game
+ /// Utility to get the state of the current Techblox game
///
public static class GameState
{
@@ -34,7 +34,7 @@ namespace TechbloxModdingAPI.Utility
///
/// Is a game loaded?
///
- /// Whether Gamecraft has a game open (false = Main Menu)
+ /// Whether Techblox has a game open (false = Main Menu)
public static bool IsInGame()
{
return gameEngine.IsInGame;
diff --git a/TechbloxModdingAPI/Utility/GameStateEngine.cs b/TechbloxModdingAPI/Utility/GameStateEngine.cs
index 3861d00..936a8ef 100644
--- a/TechbloxModdingAPI/Utility/GameStateEngine.cs
+++ b/TechbloxModdingAPI/Utility/GameStateEngine.cs
@@ -12,7 +12,7 @@ namespace TechbloxModdingAPI.Utility
{
class GameStateEngine : IApiEngine
{
- public string Name { get; } = "GamecraftModdingAPIGameStateGameEngine";
+ public string Name { get; } = "TechbloxModdingAPIGameStateGameEngine";
public EntitiesDB entitiesDB { set; private get; }
diff --git a/TechbloxModdingAPI/Utility/Logging.cs b/TechbloxModdingAPI/Utility/Logging.cs
index d28fd76..8a26759 100644
--- a/TechbloxModdingAPI/Utility/Logging.cs
+++ b/TechbloxModdingAPI/Utility/Logging.cs
@@ -9,8 +9,8 @@ using System.Threading.Tasks;
namespace TechbloxModdingAPI.Utility
{
///
- /// Utility class to access Gamecraft's built-in logging capabilities.
- /// The log is saved to %APPDATA%\..\LocalLow\FreeJam\Gamecraft\Player.Log
+ /// Utility class to access Techblox's built-in logging capabilities.
+ /// The log is saved to %APPDATA%\..\LocalLow\FreeJam\Techblox\Player.Log
///
public static class Logging
{
@@ -21,7 +21,7 @@ namespace TechbloxModdingAPI.Utility
}
///
- /// Write a regular message to Gamecraft's log
+ /// Write a regular message to Techblox's log
///
/// The object to log
[MethodImpl(MethodImplOptions.AggressiveInlining)]
@@ -37,7 +37,7 @@ namespace TechbloxModdingAPI.Utility
}
///
- /// Write a debug message to Gamecraft's log
+ /// Write a debug message to Techblox's log
///
/// The object to log
[MethodImpl(MethodImplOptions.AggressiveInlining)]
@@ -53,7 +53,7 @@ namespace TechbloxModdingAPI.Utility
}
///
- /// Write a debug message and object to Gamecraft's log
+ /// Write a debug message and object to Techblox's log
/// The reason this method exists in Svelto.Console is beyond my understanding
///
/// The type of the extra debug object
@@ -72,7 +72,7 @@ namespace TechbloxModdingAPI.Utility
}
///
- /// Write an error message to Gamecraft's log
+ /// Write an error message to Techblox's log
///
/// The object to log
/// The extra data to pass to the ILogger
@@ -83,7 +83,7 @@ namespace TechbloxModdingAPI.Utility
}
///
- /// Write an exception to Gamecraft's log and to the screen and exit game
+ /// Write an exception to Techblox's log and to the screen and exit game
///
/// The exception to log
/// The extra data to pass to the ILogger.
@@ -95,7 +95,7 @@ namespace TechbloxModdingAPI.Utility
}
///
- /// Write an exception message to Gamecraft's log and to the screen and exit game
+ /// Write an exception message to Techblox's log and to the screen and exit game
///
/// The object to log
/// The exception to log
@@ -114,7 +114,7 @@ namespace TechbloxModdingAPI.Utility
}
///
- /// Write a warning message to Gamecraft's log
+ /// Write a warning message to Techblox's log
///
/// The object to log
[MethodImpl(MethodImplOptions.AggressiveInlining)]
@@ -144,7 +144,7 @@ namespace TechbloxModdingAPI.Utility
// descriptive logging
///
- /// Write a descriptive message to Gamecraft's log only when the API is a Debug build
+ /// Write a descriptive message to Techblox's log only when the API is a Debug build
///
/// The object to log
[MethodImpl(MethodImplOptions.AggressiveInlining)]
@@ -156,7 +156,7 @@ namespace TechbloxModdingAPI.Utility
}
///
- /// Write a descriptive message to Gamecraft's log including the current time and the calling method's name
+ /// Write a descriptive message to Techblox's log including the current time and the calling method's name
///
/// The object to log
[MethodImpl(MethodImplOptions.AggressiveInlining)]
@@ -169,7 +169,7 @@ namespace TechbloxModdingAPI.Utility
// CLI logging
///
- /// Write a message to Gamecraft's command line
+ /// Write a message to Techblox's command line
///
/// The object to log
[MethodImpl(MethodImplOptions.AggressiveInlining)]
@@ -185,7 +185,7 @@ namespace TechbloxModdingAPI.Utility
}
///
- /// Write an error message to Gamecraft's command line
+ /// Write an error message to Techblox's command line
///
/// The object to log
[MethodImpl(MethodImplOptions.AggressiveInlining)]
@@ -201,7 +201,7 @@ namespace TechbloxModdingAPI.Utility
}
///
- /// Write a warning message to Gamecraft's command line
+ /// Write a warning message to Techblox's command line
///
/// The object to log
[MethodImpl(MethodImplOptions.AggressiveInlining)]
diff --git a/TechbloxModdingAPI/Utility/VersionTracking.cs b/TechbloxModdingAPI/Utility/VersionTracking.cs
index 82d39d3..01da552 100644
--- a/TechbloxModdingAPI/Utility/VersionTracking.cs
+++ b/TechbloxModdingAPI/Utility/VersionTracking.cs
@@ -61,7 +61,7 @@ namespace TechbloxModdingAPI.Utility
[Obsolete]
internal class VersionTrackingEngine : IEventEmitterEngine
{
- public string Name { get; } = "GamecraftModdingAPIVersionTrackingGameEngine";
+ public string Name { get; } = "TechbloxModdingAPIVersionTrackingGameEngine";
public EntitiesDB entitiesDB { set; private get; }
@@ -104,7 +104,7 @@ namespace TechbloxModdingAPI.Utility
[Obsolete]
public class ModVersionDescriptor: SerializableEntityDescriptor
{
- [HashName("GamecraftModdingAPIVersionV0")]
+ [HashName("TechbloxModdingAPIVersionV0")]
public class _ModVersionDescriptor : IEntityDescriptor
{
public IComponentBuilder[] componentsToBuild { get; } = new IComponentBuilder[]{
diff --git a/TechbloxModdingAPI/Interface/IMGUI/Constants.cs b/TechbloxModdingAPI/Interface/IMGUI/Constants.cs
index a34d8fe..a966a5f 100644
--- a/TechbloxModdingAPI/Interface/IMGUI/Constants.cs
+++ b/TechbloxModdingAPI/Interface/IMGUI/Constants.cs
@@ -22,9 +22,9 @@ namespace TechbloxModdingAPI.Interface.IMGUI
private static GUISkin _default = null;
///
/// Best-effort imitation of Gamecraft's UI style.
///
- public static GUISkin Default
+ public static GUISkin Default //TODO: Update to Techblox style
{
get
{
@@ -122,7 +122,7 @@ namespace TechbloxModdingAPI.Interface.IMGUI
_defaultCompletion++;
};
_blueBackground = new Texture2D(1, 1);
- _blueBackground.SetPixel(0, 0, new Color(0.004f, 0.522f, 0.847f) /* Gamecraft Blue */);
+ _blueBackground.SetPixel(0, 0, new Color(0.004f, 0.522f, 0.847f) /* Techblox Blue */);
_blueBackground.Apply();
_grayBackground = new Texture2D(1, 1);
_grayBackground.SetPixel(0, 0, new Color(0.745f, 0.745f, 0.745f) /* Gray */);
@@ -22,9 +22,9 @@ namespace TechbloxModdingAPI.Interface.IMGUI
private static GUISkin _default = null;
///
- /// Best-effort imitation of Gamecraft's UI style.
+ /// Best-effort imitation of Techblox's UI style.
///
diff --git a/TechbloxModdingAPI/Main.cs b/TechbloxModdingAPI/Main.cs
index b81e127..da66884 100644
--- a/TechbloxModdingAPI/Main.cs
+++ b/TechbloxModdingAPI/Main.cs
@@ -31,7 +31,7 @@ namespace TechbloxModdingAPI
///
/// Initializes the TechbloxModdingAPI.
/// Call this as soon as possible after Gamecraft starts up.
/// Ideally, this should be called from your main Plugin class's OnApplicationStart() method.
///
public static void Init()
@@ -43,7 +43,7 @@ namespace TechbloxModdingAPI
Logging.LogWarning("TechbloxModdingAPI.Main.Init() called but API is already initialized!");
return;
}
- Logging.MetaDebugLog($"Patching Gamecraft");
+ Logging.MetaDebugLog($"Patching Techblox");
var currentAssembly = Assembly.GetExecutingAssembly();
harmony = new Harmony(currentAssembly.GetName().Name);
try
@@ -53,7 +53,7 @@ namespace TechbloxModdingAPI
catch (Exception e)
{ //Can't use ErrorBuilder or Logging.LogException (which eventually uses ErrorBuilder) yet
Logging.Log(e.ToString());
- Logging.LogWarning("Failed to patch Gamecraft. Attempting to patch to display error...");
+ Logging.LogWarning("Failed to patch Techblox. Attempting to patch to display error...");
harmony.Patch(AccessTools.Method(typeof(FullGameCompositionRoot), "OnContextInitialized")
.MakeGenericMethod(typeof(UnityContext)),
new HarmonyMethod(((Action) OnPatchError).Method)); //Can't use lambdas here :(
@@ -67,12 +67,12 @@ namespace TechbloxModdingAPI
Utility.VersionTracking.Init();
// create default event emitters
Logging.MetaDebugLog($"Initializing Events");
- EventManager.AddEventEmitter(new SimpleEventEmitterEngine(EventType.ApplicationInitialized, "GamecraftModdingAPIApplicationInitializedEventEmitter", false));
- EventManager.AddEventEmitter(new SimpleEventEmitterEngine(EventType.Menu, "GamecraftModdingAPIMenuActivatedEventEmitter", false));
- EventManager.AddEventEmitter(new SimpleEventEmitterEngine(EventType.MenuSwitchedTo, "GamecraftModdingAPIMenuSwitchedToEventEmitter", false));
- EventManager.AddEventEmitter(new SimpleEventEmitterEngine(EventType.Game, "GamecraftModdingAPIGameActivatedEventEmitter", false));
- EventManager.AddEventEmitter(new SimpleEventEmitterEngine(EventType.GameReloaded, "GamecraftModdingAPIGameReloadedEventEmitter", false));
- EventManager.AddEventEmitter(new SimpleEventEmitterEngine(EventType.GameSwitchedTo, "GamecraftModdingAPIGameSwitchedToEventEmitter", false));
+ EventManager.AddEventEmitter(new SimpleEventEmitterEngine(EventType.ApplicationInitialized, "TechbloxModdingAPIApplicationInitializedEventEmitter", false));
+ EventManager.AddEventEmitter(new SimpleEventEmitterEngine(EventType.Menu, "TechbloxModdingAPIMenuActivatedEventEmitter", false));
+ EventManager.AddEventEmitter(new SimpleEventEmitterEngine(EventType.MenuSwitchedTo, "TechbloxModdingAPIMenuSwitchedToEventEmitter", false));
+ EventManager.AddEventEmitter(new SimpleEventEmitterEngine(EventType.Game, "TechbloxModdingAPIGameActivatedEventEmitter", false));
+ EventManager.AddEventEmitter(new SimpleEventEmitterEngine(EventType.GameReloaded, "TechbloxModdingAPIGameReloadedEventEmitter", false));
+ EventManager.AddEventEmitter(new SimpleEventEmitterEngine(EventType.GameSwitchedTo, "TechbloxModdingAPIGameSwitchedToEventEmitter", false));
EventManager.AddEventEmitter(GameHostTransitionDeterministicGroupEnginePatch.buildEngine);
EventManager.AddEventEmitter(GameHostTransitionDeterministicGroupEnginePatch.simEngine);
#pragma warning restore 0612,0618
@@ -100,7 +100,7 @@ namespace TechbloxModdingAPI
///
/// Shuts down & cleans up the TechbloxModdingAPI.
/// Call this as late as possible before Gamecraft quits.
/// Ideally, this should be called from your main Plugin class's OnApplicationQuit() method.
///
public static void Shutdown()
@@ -31,7 +31,7 @@ namespace TechbloxModdingAPI
///
/// Initializes the TechbloxModdingAPI.
- /// Call this as soon as possible after Gamecraft starts up.
+ /// Call this as soon as possible after Techblox starts up.
/// Ideally, this should be called from your main Plugin class's OnApplicationStart() method.
///
@@ -100,7 +100,7 @@ namespace TechbloxModdingAPI
///
/// Shuts down & cleans up the TechbloxModdingAPI.
- /// Call this as late as possible before Gamecraft quits.
+ /// Call this as late as possible before Techblox quits.
/// Ideally, this should be called from your main Plugin class's OnApplicationQuit() method.
///
diff --git a/TechbloxModdingAPI/Tasks/Scheduler.cs b/TechbloxModdingAPI/Tasks/Scheduler.cs
index af47d1d..764e9b7 100644
--- a/TechbloxModdingAPI/Tasks/Scheduler.cs
+++ b/TechbloxModdingAPI/Tasks/Scheduler.cs
@@ -32,9 +32,9 @@ namespace TechbloxModdingAPI.Tasks
}
}
- public static readonly Svelto.Tasks.ExtraLean.Unity.UpdateMonoRunner extraLeanRunner = new Svelto.Tasks.ExtraLean.Unity.UpdateMonoRunner("GamecraftModdingAPIExtraLean");
+ public static readonly Svelto.Tasks.ExtraLean.Unity.UpdateMonoRunner extraLeanRunner = new Svelto.Tasks.ExtraLean.Unity.UpdateMonoRunner("TechbloxModdingAPIExtraLean");
- public static readonly Svelto.Tasks.Lean.Unity.UpdateMonoRunner leanRunner = new Svelto.Tasks.Lean.Unity.UpdateMonoRunner("GamecraftModdingAPILean");
+ public static readonly Svelto.Tasks.Lean.Unity.UpdateMonoRunner leanRunner = new Svelto.Tasks.Lean.Unity.UpdateMonoRunner("TechbloxModdingAPILean");
///
/// Schedule a task to run asynchronously.
@@ -42,7 +42,7 @@ namespace TechbloxModdingAPI.Tasks
///
/// The task to run
/// Schedule toRun on an extra lean runner?
/// Schedule toRun on Gamecraft's built-in UI task runner?
public static void Schedule(ISchedulable toRun, bool extraLean = false, bool ui = false)
{
if (extraLean)
@@ -42,7 +42,7 @@ namespace TechbloxModdingAPI.Tasks
/// The task to run
/// Schedule toRun on an extra lean runner?
- /// Schedule toRun on Gamecraft's built-in UI task runner?
+ /// Schedule toRun on Techblox's built-in UI task runner?
public static void Schedule(ISchedulable toRun, bool extraLean = false, bool ui = false)
{